@@ -351,12 +351,15 @@ class Text(EmbeddedTextBlock):
 
     def __init__(self, text: str = None, file: NPath = None, id: str = None, label: str = None):
         """
-        Args:
+        Args:te
             text: The markdown formatted text, use triple-quotes, (`\"\"\"# My Title\"\"\"`) to create multi-line markdown text
+            file: Path to a file containing markdown text
             id: A unique id for the block to aid querying (optional)
         """
         super().__init__(id=id, label=label)
 
+        if text:
+            text = text.strip()
         assert text or file
         self.content = text if text else Path(file).read_text()
 
@@ -673,6 +676,8 @@ class DataTable(AssetBlock):
     and can be downloaded by them as a CSV or Excel file.
 
     ..tip:: For smaller dataframes where you don't require sorting and filtering, also consider using the `Table` block
+    ..note:: The DataTable component requires a server and is not supported when saving locally, please publish such reports to a Datapane Server or use dp.Table
+
     """
 
     _tag = "DataTable"
